<? 

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

if ( ! class_exists( 'WC_Email' ) ) {
    return;
}

class WC_Customer_Cancel_Order extends WC_Email {

    public function __construct() {

        $this->id          = 'wc_customer_cancelled_order';
        $this->title       = __( 'Cancelled Order to Customer', 'custom-wc-email' );
        $this->description = __( 'An email sent to the customer when an order is cancelled.', 'custom-wc-email' );
        $this->customer_email = true;
        $this->heading     = __( 'Order Cancelled', 'custom-wc-email' );
        $this->subject     = sprintf( _x( '[%s] Order Cancelled', 'default email subject for cancelled emails sent to the customer', 'custom-wc-email' ), '{blogname}' );
    
        $this->template_html  = 'emails/wc-customer-cancelled-order.php';
        $this->template_plain = 'emails/plain/wc-customer-cancelled-order.php';
        $this->template_base  = CUSTOM_WC_EMAIL_PATH . 'templates/';
    
        add_action( 'woocommerce_order_status_processing_to_cancelled_notification', array( $this, 'trigger' ), 10, 2 );
        add_action( 'woocommerce_order_status_on-hold_to_cancelled_notification', array( $this, 'trigger' ), 10, 2 );

        parent::__construct();
    }
    
    public function trigger( $order_id ) {
        $this->object = wc_get_order( $order_id );

        if ( version_compare( '3.0.0', WC()->version, '>' ) ) {
            $order_email = $this->object->billing_email;
        } else {
            $order_email = $this->object->get_billing_email();
        }

        $this->recipient = $order_email;


        if ( ! $this->is_enabled() || ! $this->get_recipient() ) {
            return;
        }

        $this->send( $this->get_recipient(), $this->get_subject(), $this->get_content(), $this->get_headers(), $this->get_attachments() );
    }

    public function get_content_html() {
        return wc_get_template_html( $this->template_html, array(
            'order'         => $this->object,
            'email_heading' => $this->get_heading(),
            'sent_to_admin' => false,
            'plain_text'    => false,
            'email'         => $this
        ), '', $this->template_base );
    }

    public function get_content_plain() {
        return wc_get_template_html( $this->template_plain, array(
            'order'         => $this->object,
            'email_heading' => $this->get_heading(),
            'sent_to_admin' => false,
            'plain_text'    => true,
            'email'         => $this
        ), '', $this->template_base );
    }
}